<?php

namespace Drupal\drupalorg\Commands;

use Drupal\taxonomy\Entity\Term;
use Drush\Commands\DrushCommands as BaseDrushCommands;

/**
 * A drush command file.
 *
 * @package Drupal\drush9_custom_commands\Commands
 */
class DrushCommands extends BaseDrushCommands {

  /**
   * Grabs all SVG icons from a theme directory and populates 'icons' taxonomy.
   *
   * @command drupalorg:populate-icons
   * @usage drush drupalorg:populate-icons
   */
  public function populateIcons() {
    $directory = \Drupal::service('extension.list.theme')->getPath('drupalorg_theme') . '/src/assets/svgs';
    $filesystem = \Drupal::service('file_system');
    $files = $filesystem->scanDirectory($directory, '/^icon-.*\.svg$/');
    $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadTree('icons');

    // Delete existing terms.
    foreach ($terms as $term) {
      $term_entity = Term::load($term->tid);
      $term_entity->delete();
    }

    foreach ($files as $file) {
      $filename = pathinfo($file->uri)['filename'];
      $term_name = str_replace('-', ' ', $filename);
      if (strpos($term_name, 'icon ') === 0) {
        $term_name = substr($term_name, 5);
      }
      $term_name = ucwords($term_name);

      $term = Term::create([
        'vid' => 'icons',
        'name' => $term_name,
      ]);
      $this->output()->writeln("Creating icon taxonomy: $term_name");
      $term->save();
    }
  }

}
