<?php

namespace Drupal\drupalorg\Utilities;

use Drupal\drupalorg\Traits\UpdateXML;
use Drupal\node\Entity\Node;
use Drupal\node\NodeInterface;

/**
 * Utility functions to calculate and populate the composer namespace values.
 */
class ComposerNamespace {

  use UpdateXML;

  /**
   * Calculate the composer namespace for the projects.
   */
  public static function calculateNamespace($set_default_if_none_found = TRUE) {
    $ids = self::getProjectsWithNoComposerNamespace();
    foreach ($ids as $id) {
      $updated = FALSE;
      $project = Node::load($id);
      $machine_name = $project->get('field_project_machine_name')->getValue()[0]['value'];
      $info = self::getProjectInformation($machine_name);
      if (!empty($info)) {
        $composer_namespace = $info['composer_namespace'] ?? NULL;
        if ($composer_namespace) {
          $updated = TRUE;
          $project
            ->set('field_composer_namespace', $composer_namespace)
            ->save();
        }
      }

      if ($set_default_if_none_found && !$updated) {
        $project
          ->set('field_composer_namespace', 'drupal/' . $machine_name)
          ->save();
      }
    }
  }

  /**
   * Get projects with no composer namespace.
   *
   * @return array
   *   List of projects that match the condition.
   */
  protected static function getProjectsWithNoComposerNamespace(): array {
    return \Drupal::entityQuery('node')
      ->accessCheck(FALSE)
      ->condition('type', 'project_module')
      ->condition('status', NodeInterface::PUBLISHED)
      ->notExists('field_composer_namespace')
      ->execute();
  }

}
