<?php

namespace Drupal\drupalorg\Utilities;

use Drupal\drupalorg\Traits\GitLabClientTrait;
use Drupal\node\Entity\Node;
use Drupal\node\NodeInterface;

/**
 * Utility functions to fetch the project logo hosted on GitLab.
 */
class GitLabLogoFetcher {

  use GitLabClientTrait;

  /**
   * Calculate the composer namespace for the projects.
   */
  public function setAvatarsAsLogos($set_default_value_if_none_found = FALSE) {
    $client = $this->getGitLabClient();
    $ids = $this->getProjectsWithComposerNamespaceAndNoLogo();
    foreach ($ids as $id) {
      $updated = FALSE;
      $project = Node::load($id);
      $composer_namespace = $project->get('field_composer_namespace')->getValue()[0]['value'];
      $gitlab_namespace = str_replace('drupal/', 'project/', $composer_namespace);
      try {
        $gitlab_project = $client->projects()->show($gitlab_namespace);
        $avatar = $gitlab_project['avatar_url'] ?? NULL;
        if ($avatar) {
          $updated = TRUE;
          $project->set('field_logo_url', $avatar)->save();
        }

        if ($set_default_value_if_none_found && !$updated) {
          // This is a magic URL that will work once the project has an avatar.
          $avatar = $gitlab_project['web_url'] . '/-/avatar';
          $project->set('field_logo_url', $avatar)->save();
        }
      }
      catch (\Throwable $e) {
        // If the project is not found there is nothing we can do.
      }
    }
  }

  /**
   * Get projects with composer namespace and no logo.
   *
   * @return array
   *   List of projects that match the condition.
   */
  protected function getProjectsWithComposerNamespaceAndNoLogo(): array {
    return \Drupal::entityQuery('node')
      ->accessCheck(FALSE)
      ->condition('type', 'project_module')
      ->condition('status', NodeInterface::PUBLISHED)
      ->exists('field_composer_namespace')
      ->notExists('field_logo_url')
      ->execute();
  }

}
